@@ -71,45 +71,11 @@ eccons=c("c","ec","ecS","ce","ceS")
 
 g = 9.81
 
-smoothingAll= 0.1
-
 colSpeed="springgreen3"; colForce="blue2"; colPower="tomato2"	#colors
 #colSpeed="black"; colForce="black"; colPower="black"		#black & white
 cols=c(colSpeed,colForce,colPower); lty=rep(1,3)	
 
 
-#--- user commands ---
-#way A. passing options to a file
-getOptionsFromFile <- function(optionsFile) {
-	optionsCon <- file(optionsFile, 'r')
-	options=readLines(optionsCon,n=31)
-	close(optionsCon)
-	return (options)
-}
-
-#way B. put options as arguments
-#unused because maybe command line gets too long
-#options <- commandArgs(TRUE)
-
-
-args <- commandArgs(TRUE)
-optionsFile =args[1]
-
-print(optionsFile)
-
-options=getOptionsFromFile(optionsFile)
-
-#print(options)
-
-OutputData2 = options[4] #currently used to display processing feedback
-SpecialData = options[5]
-OperatingSystem=options[27]
-EncoderConfigurationName = ""
-
-English = unlist(strsplit(options[30], "\\;"))
-Translated = unlist(strsplit(options[31], "\\;"))
-
-
 #translate
 translate <- function(englishWord) {
 	if(length(Translated[which(English == englishWord)]) == 0)
@@ -118,8 +84,6 @@ translate <- function(englishWord) {
 		return(Translated[which(English == englishWord)])
 }
 
-write(paste("(1/5)",translate("Starting R")), OutputData2)
-
 
 # This function converts top curve into bottom curve
 #
@@ -213,7 +177,7 @@ getDisplacementInertialBody <- function(displacement, draw, title)
 
 		title(title, cex.main=1, font.main=1)
 		mtext(paste(translate("time"),"(s)"),side=1,adj=1,line=-1)
-		mtext(paste(translate("height"),"(cm)"),side=2,adj=1,line=-1)
+		mtext(paste(translate("displacement"),"(cm)"),side=2,adj=1,line=-1)
 	}
 	return(displacementPerson)
 }
@@ -347,7 +311,7 @@ findCurves <- function(displacement, eccon, min_height, draw, title) {
 
 		title(title, cex.main=1, font.main=1)
 		mtext(paste(translate("time"),"(s)"),side=1,adj=1,line=-1)
-		mtext(paste(translate("height"),"(cm)"),side=2,adj=1,line=-1)
+		mtext(paste(translate("displacement"),"(cm)"),side=2,adj=1,line=-1)
 	}
 	return(as.data.frame(cbind(start,end,startH)))
 }
@@ -549,7 +513,15 @@ findECPhases <- function(displacement,speed) {
 	eccentric = 0
 	isometric = 0
 	concentric = 0
-				
+
+	#temporary fix problem of found MinSpeedEnd at right
+	if(searchMinSpeedEnd > searchMaxSpeedIni)
+		return(list(
+			    eccentric=0,
+			    isometric=0,
+			    concentric=0))
+
+
 	isometricUse = TRUE
 	if(isometricUse) {
 		eccentric=1:min(speed.ext$cross[crossMinRow,1])
@@ -566,14 +538,24 @@ findECPhases <- function(displacement,speed) {
 		concentric=concentric))
 }
 
-#TODO: this can have problems if there's an initial brake when lifting and this goes under -9.8
-#better use extrema, and if there's more than one minindex:
-#take the last minindex and it's previous maxindex
-#go from that maxindex to the minindex and on the first moment that goes under -9.8 assign propulsiveEnd there
-#Also use more this funcion (eg on paint)
-findPropulsiveEnd <- function(accel, concentric) {
-	if(length(which(accel[concentric]<=-g)) > 0) 
-		propulsiveEnd = min(which(accel[concentric] <= -g))
+findPropulsiveEnd <- function(accel, concentric, maxSpeedTInConcentric) {
+	if(length(which(accel[concentric]<=-g)) > 0) {
+		#this can be a problem because some people does an strange countermovement at start of concentric movement
+		#this people moves arms down and legs go up
+		#at this moment acceleration can be lower than -g
+		#if this happens, propulsiveEnd will be very early and detected jump will be very high
+		#propulsiveEnd = min(which(accel[concentric] <= -g))
+		#is exactly the same problem than findTakeOff, see that method for further help
+		#another option can be using extrema
+
+		accelCon = accel[concentric]
+		df=data.frame(accelCon <= -g, accelCon, abs(1:length(accelCon)-maxSpeedTInConcentric))
+		colnames(df)=c("belowG","accel","dist")
+		df2 = subset(df,subset=df$belowG)
+	
+		df2row = min(which(df2$dist == min(df2$dist)))
+		propulsiveEnd = as.integer(rownames(df2)[df2row])
+	}
 	else
 		propulsiveEnd = length(concentric)
 	
@@ -607,10 +589,10 @@ print(c(" smoothing:",smoothing))
 	else
 		accel=list(y=rep(0,length(displacement)))
 
-print(c(" ms",round(mean(speed$y),5)," ma",round(mean(accel$y),5)))
-print(c(" Ms",round(max(speed$y),5)," Ma",round(max(accel$y),5)))
-print(c(" |ms|",round(mean(abs(speed$y)),5)," |ma|:",round(mean(abs(accel$y)),5)))
-print(c(" |Ms|",round(max(abs(speed$y)),5)," |Ma|",round(max(abs(accel$y)),5)))
+	#print(c(" ms",round(mean(speed$y),5)," ma",round(mean(accel$y),5)))
+	#print(c(" Ms",round(max(speed$y),5)," Ma",round(max(accel$y),5)))
+	#print(c(" |ms|",round(mean(abs(speed$y)),5)," |ma|:",round(mean(abs(accel$y)),5)))
+	#print(c(" |Ms|",round(max(abs(speed$y)),5)," |Ma|",round(max(abs(accel$y)),5)))
 
 	#speed comes in mm/ms when derivate to accel its mm/ms^2 to convert it to m/s^2 need to *1000 because it's quadratic
 	accel$y <- accel$y * 1000 
@@ -625,14 +607,27 @@ print(c(" |Ms|",round(max(abs(speed$y)),5)," |Ma|",round(max(abs(accel$y)),5)))
 	if(isPropulsive) {
 		if(eccon=="c") {
 			concentric=1:length(displacement)
-			propulsiveEnd = findPropulsiveEnd(accel$y,concentric)
+			
+			maxSpeedT <- min(which(speed$y == max(speed$y)))
+			maxSpeedTInConcentric = maxSpeedT
+			
+			propulsiveEnd = findPropulsiveEnd(accel$y,concentric,maxSpeedTInConcentric)
 		} else if(eccon=="ec") {
 			phases=findECPhases(displacement,speed$y)
 			eccentric = phases$eccentric
 			isometric = phases$isometric
 			concentric = phases$concentric
-			propulsiveEnd = length(eccentric) + length(isometric) + findPropulsiveEnd(accel$y,concentric)
-			print(c("lengths: ", length(eccentric), length(isometric), findPropulsiveEnd(accel$y,concentric), propulsiveEnd))
+	
+			#temporary fix problem of found MinSpeedEnd at right
+			if(eccentric == 0 && isometric == 0 && concentric == 0)
+				propulsiveEnd = length(displacement)
+			else {
+				maxSpeedT <- min(which(speed$y == max(speed$y)))
+				maxSpeedTInConcentric = maxSpeedT - (length(eccentric) + length(isometric))
+
+				propulsiveEnd = length(eccentric) + length(isometric) + findPropulsiveEnd(accel$y,concentric,maxSpeedTInConcentric)
+				#print(c("lengths: ", length(eccentric), length(isometric), findPropulsiveEnd(accel$y,concentric), propulsiveEnd))
+			}
 		} else if(eccon=="e") {
 			#not eccon="e" because not propulsive calculations on eccentric
 		} else { #ecS
@@ -937,6 +932,10 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 			mtext(text=paste(" ",translate("concentric"),sep=""),side=3,at=min(concentric),cex=.8,adj=0,col=cols[1],line=.5)
 		}
 	}
+	
+	maxSpeedTInConcentric = maxSpeedT
+	if(eccon != "c")
+		maxSpeedTInConcentric = maxSpeedT - (length(eccentric) + length(isometric))
 		
 	#on rotatory inertial, concentric-eccentric, use speed as ABS)
 	#if(inertialType == "ri" && eccon == "ce")
@@ -956,7 +955,7 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	propulsiveEnd = length(displacement)
 
 	if(isPropulsive) {
-		propulsiveEnd = findPropulsiveEnd(accel$y, concentric)
+		propulsiveEnd = findPropulsiveEnd(accel$y, concentric, maxSpeedTInConcentric)
 		if(eccon != "c")
 			propulsiveEnd = length(eccentric) + length(isometric) + propulsiveEnd
 	}
@@ -1063,7 +1062,6 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 		}
 	}
 
-	
 	#mark when it's air and land
 	#if it was a eccon concentric-eccentric, will be useful to calculate flight time
 	#but this eccon will be not done
@@ -1093,7 +1091,18 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 		if(length(which(force[concentric] <= 0)) == 0)
 			takeoff = -1
 		else {
-			takeoff = min(which(force[concentric]<=0)) + length_eccentric + length_isometric
+			#1 get force only in concentric phase
+			forceConcentric = force[concentric]
+			print(c("forceConcentric",forceConcentric))
+
+			#2 get takeoff using maxSpeedT but relative to concentric, not all the ecc-con
+			
+			takeoff = findTakeOff(forceConcentric, maxSpeedTInConcentric)
+
+			#3 add eccentric and isometric
+			takeoff = takeoff + length_eccentric + length_isometric
+			print(c("takeoff",takeoff))
+			
 			abline(v=takeoff,lty=1,col=cols[2]) 
 			mtext(text=paste(translate("land")," ",sep=""),side=3,at=takeoff,cex=.8,adj=1,col=cols[2])
 			mtext(text=paste(" ", translate("air"), " ",sep=""),side=3,at=takeoff,cex=.8,adj=0,col=cols[2])
@@ -1112,14 +1121,16 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 				mtext(text=paste(" ",translate("land")," ",sep=""),side=3,at=landing,cex=.8,adj=0,col=cols[2])
 			}
 		}
-	
-		if(takeoff != -1)	
+
+		print(c(is.numeric(takeoff), takeoff))
+		if(is.numeric(takeoff) && takeoff != -1) {
 			mtext(text=paste(translate("jump height"),"=", 
 					 (position[concentric[length(concentric)]] - 
 					  position[concentric[(takeoff - length_eccentric - length_isometric)]])/10,
 					 "cm",sep=" "),
 			      side=3, at=( takeoff + (length_eccentric + length(concentric)) )/2,
 			      cex=.8,adj=0.5,col=cols[2])
+		}
 	}
 
 
@@ -1253,7 +1264,7 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 		}
 		if(showLabels) {
 			mtext(paste(translate("time"),"(ms)"),side=1,adj=1,line=-1,cex=.9)
-			mtext(paste(translate("height"),"(mm)"),side=2,adj=1,line=-1,cex=.9)
+			mtext(paste(translate("displacement"),"(mm)"),side=2,adj=1,line=-1,cex=.9)
 		}
 	}
 }
@@ -1290,11 +1301,11 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, Eccon, height, n, sh
 	#peakPower is always ABS
 	if(Eccon == "c") {
 		powerName = translate("Power")
-		peakPowerName = paste(translate("Peak Power"),"(ABS)")
+		peakPowerName = translate("Peak Power")
 	}
 	else {
-		powerName = paste(translate("Power"),"(ABS)")
-		peakPowerName = paste(translate("Peak Power"),"(ABS)")
+		powerName = translate("Power")
+		peakPowerName = translate("Peak Power")
 	}
 
 	print("powerData")
@@ -1318,7 +1329,8 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, Eccon, height, n, sh
 			xlab="",ylab=paste(translate("Power"),"(W)"), 
 			ylim=c(lowerY,max(powerData)), xpd=FALSE) #ylim, xpd = F,  makes barplot starts high (compare between them)
 	title(main=title,line=-2,outer=T)
-	mtext(paste(translate("Curve")," \n",translate("Load")," ",sep=""),side=1,at=1,adj=1,line=1,cex=.9)
+	box()
+	mtext(paste(translate("Curve")," \n",translate("Mass")," ",sep=""),side=1,at=1,adj=1,line=1,cex=.9)
 
 	axisLineRight=0
 
@@ -1427,19 +1439,98 @@ findPosInPaf <- function(var, option) {
 	return(pos)
 }
 
-addUnits <- function (var) {
+addUnitsAndTranslate <- function (var) {
 	if(var == "Speed")
 		return (paste(translate("Speed"),"(m/s)"))
 	else if(var == "Power")
 		return (paste(translate("Power"),"(W)"))
 	else if(var == "Load") #or Mass
-		return (paste(translate("Load"),"(Kg)"))
+		return (paste(translate("Mass"),"(Kg)"))
 	else if(var == "Force")
 		return (paste(translate("Force"),"(N)"))
 
 	return(var)
 }
 
+#if num is >= 0, plot '+'.
+#else plot ''. (because the number will be displayed as negative)
+#this is to avoid having a '+ -'
+plotSign <- function (num) {
+	if(num >= 0)
+		return('+')
+	else
+		return('')
+}
+
+getModelPValueWithStars <- function(model) {
+	p.value = round(getModelPValue(model),6)
+	
+	#don't plot stars if p.value is nan because there's too few data
+	if(is.nan(p.value))
+		return (p.value)
+
+	stars = ""
+	if(p.value <= 0.0001)
+		stars = "***"
+	else if(p.value <= 0.001)
+		stars = "**"
+	else if(p.value <= 0.05)
+		stars = "*"
+	else if(p.value <= 0.01)
+		stars = "."
+	return(paste(p.value, " ", stars, sep=""))
+}
+#http://r.789695.n4.nabble.com/extract-the-p-value-tp3933973p3934011.html
+getModelPValue <- function(model) {
+	stopifnot(inherits(model, "lm"))
+	s <- summary.lm(model)
+	pf(s$fstatistic[1L], s$fstatistic[2L], s$fstatistic[3L], lower.tail = FALSE)
+}
+
+#http://stackoverflow.com/a/6234664
+#see if two labels overlap
+stroverlap <- function(x1,y1,s1, x2,y2,s2) {
+	print(c(x1,y1,s1, x2,y2,s2))
+	sh1 <- strheight(s1)
+	sw1 <- strwidth(s1)
+	sh2 <- strheight(s2)
+	sw2 <- strwidth(s2)
+
+	overlap <- FALSE
+	if (x1<x2) 
+		overlap <- x1 + sw1 > x2
+	else
+		overlap <- x2 + sw2 > x1
+
+	if (y1<y2)
+		overlap <- overlap && (y1 +sh1>y2)
+	else
+		overlap <- overlap && (y2+sh2>y1)
+
+	return(overlap)
+}
+#check all labels to see if newPoint overlaps one of them
+stroverlapArray <- function(newPoint, points) {
+	overlap = FALSE
+			
+	#print(c("at Array newPoint, points",newPoint, points))
+	if(length(points$x) == 1)	#if there's only one row
+		return (stroverlap(
+			      as.numeric(newPoint[1]), as.numeric(newPoint[2]), newPoint[3],
+			      as.numeric(points$x), as.numeric(points$y), points$curveNum ))
+	
+	#as.numeric is needed because ec-con uses "1e" in third element, and then three elements are strings
+
+	for(i in 1:length(points$x)) {	#for every row
+		overlap = stroverlap(
+			      as.numeric(newPoint[1]), as.numeric(newPoint[2]), newPoint[3],
+			      as.numeric(points$x[i]), as.numeric(points$y[i]), points$curveNum[i])
+		if(overlap)
+			return (TRUE)
+	}
+	return (FALSE)
+}
+
 #option: mean or max
 paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, singleFile, Eccon, seriesName, do1RM, do1RMMethod, outputData1) {
 	x = (paf[,findPosInPaf(varX, option)])
@@ -1451,37 +1542,21 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, single
 	colBalls = NULL
 	bgBalls = NULL
 
-	varX = addUnits(varX)
-	varY = addUnits(varY)
+	isPowerLoad = FALSE
+	if(varX == "Load" && varY == "Power")
+		isPowerLoad = TRUE
+
+	varXut = addUnitsAndTranslate(varX)
+	varYut = addUnitsAndTranslate(varY)
+	
+	#nums.print.df = NULL
+	nums.print = NULL
 
 	#if only one series
 	if(length(unique(seriesName)) == 1) {
-		myNums = rownames(paf)
-		if(Eccon=="ecS" || Eccon=="ceS") {
-			if(singleFile) {
-				myEc=c("c","e")
-				if(Eccon=="ceS")
-					myEc=c("e","c")
-				myNums = as.numeric(rownames(paf))
-				myNums = paste(trunc((myNums+1)/2),myEc[((myNums%%2)+1)],sep="")
-			}
-		}
-
-		#problem with balls is that two values two close looks bad
-		#suboption="balls"
-		suboption="side"
-		if(suboption == "balls") {
-			cexBalls = 3
-			cexNums = 1
-			adjHor = 0.5
-			nums=myNums
-		} else if (suboption == "side") {
-			cexBalls = 1.8
-			cexNums = 1
-			adjHor = 0
-			nums=paste("  ", myNums)
-		}
-
+		cexBalls = 1.8
+		cexNums = 1
+		adjHor = 0
 		colBalls="blue"
 		bgBalls="lightBlue"
 		if(isAlone == "RIGHT") {
@@ -1489,8 +1564,36 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, single
 			bgBalls="pink"
 		}
 		
-		plot(x,y, xlab=varX, ylab="", pch=21,col=colBalls,bg=bgBalls,cex=cexBalls,axes=F)
+		plot(x,y, xlab=varXut, ylab="", pch=21,col=colBalls,bg=bgBalls,cex=cexBalls,axes=F)
 	
+
+		newPoint = c(x[1], y[1], 1) #TODO: do also for ecc-con
+		nums.print = data.frame(rbind(newPoint))
+		colnames(nums.print) = c("x","y","curveNum")
+	
+		#done after data.frame definition in order to don't mess up with string columns	
+		if( ( Eccon=="ecS" || Eccon=="ceS" ) && singleFile)
+			nums.print$curveNum = "1e"
+		
+		for(i in 2:length(x)) {
+			name = i
+			if( ( Eccon=="ecS" || Eccon=="ceS" ) && singleFile) {
+				myEc=c("c","e")
+				if(Eccon=="ceS")
+					myEc=c("e","c")
+				name = paste(trunc((name+1)/2),myEc[((name%%2)+1)],sep="")
+			}
+
+			newPoint = c(x[i], y[i], name) #TODO: do also for ecc-con
+			
+			overlaps = FALSE
+			if( ! ( is.na(x[i]) && is.na(y[i]) ) )
+				overlaps = stroverlapArray(newPoint, nums.print)
+			if(! overlaps)
+				nums.print = rbind(nums.print, newPoint)
+		}
+
+
 		if(do1RM != FALSE & do1RM != "0") {	
 			speed1RM = as.numeric(do1RM)
 
@@ -1530,11 +1633,10 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, single
 
 			load1RM = ( speed1RM - c.intercept ) / c.x
 
-			#plot(x,y, xlim=c(min(x),load1RM), ylim=c(speed1RM, max(y)), xlab=varX, ylab="", pch=21,col=colBalls,bg=bgBalls,cex=cexBalls,axes=F)
 			maxX=max(x)
 			if(load1RM > maxX)
 				maxX=load1RM
-			plot(x,y, xlim=c(min(x),maxX), ylim=c(0, max(y)), xlab=varX, ylab="", pch=21,col=colBalls,bg=bgBalls,cex=cexBalls,axes=F)
+			plot(x,y, xlim=c(min(x),maxX), ylim=c(0, max(y)), xlab=varXut, ylab="", pch=21,col=colBalls,bg=bgBalls,cex=cexBalls,axes=F)
 			abline(fit,col="red")
 			abline(h=speed1RM,col="gray",lty=2)
 			abline(v=load1RM,col="gray",lty=2)
@@ -1552,13 +1654,62 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, single
 			#lines(10:100 ,fit2line, col="red") #puts line on plot
 		}
 		else {
-			#x vector should contain at least 4 different values
-			if(length(unique(x)) >= 4)
-				lines(smooth.spline(x,y,df=4),col=colBalls,lwd=2)
+			if(length(unique(x)) >= 3) {
+				fit = lm(y ~ x + I(x^2))
+		
+				coef.a <- fit$coefficient[3]
+				coef.b <- fit$coefficient[2]
+				coef.c <- fit$coefficient[1]
+
+				x1 <- seq(min(x),max(x), (max(x) - min(x))/1000)
+				y1 <- coef.a *x1^2 + coef.b * x1 + coef.c
+				lines(x1,y1)
+
+				#start plot the function expression, R^2 and p
+				varXplot = varX
+				if(varXplot == "Load")
+					varXplot = "Mass"
+
+				#for Speed,Power graph
+				functionAt = max(x)
+				functionAdj = 1
+				if(isAlone == "LEFT") {
+					functionAt = min(x)
+					functionAdj = 0
+				}
+
+				mtext(paste(
+					    varYut, " = ", 
+					    round(coef.a,4), " * ", varXplot, "^2 ", plotSign(coef.b), " ",  
+					    round(coef.b,4), " * ", varXplot, " ", plotSign(coef.c), " ", 
+					    round(coef.c,4), sep=""), side=3, line=1, at=functionAt, adj=functionAdj, cex = .9)
+				mtext(paste(
+					    "R² = ", round(summary(fit)$r.squared,4),
+					    "; R² (adjusted) = ", round(summary(fit)$adj.r.squared,4),
+					    "; p = ", getModelPValueWithStars(fit)
+					    , sep=""), side =3, line=0, at=functionAt, adj=functionAdj, cex=.9)
+				#end of plot the function expression, R^2 and p
+	
+				if(isPowerLoad) {
+					#xmax <-  -b / 2a
+					xmax <- - coef.b / (2 * coef.a)
+
+					#pmax <- ax^2 +bx +c
+					pmax <- xmax^2 * coef.a + xmax * coef.b + coef.c
+
+					abline(v=xmax,lty=3)
+					points(xmax, pmax, pch=1, cex=3)
+
+					#this check is to not have title overlaps on 'speed,power / load' graph
+					if(title != "")
+					   title = paste(title, " (pmax = ", round(pmax,1), " W with ", round(xmax,1), " Kg)", sep="")
+				}
+			}
 		}
 		
-		title(title, cex.main=1, font.main=2)
-		text(x,y,nums,adj=c(adjHor,.5),cex=cexNums)
+		title(title, cex.main=1, font.main=2, line=3)
+		
+		text(as.numeric(nums.print$x), as.numeric(nums.print$y), paste("  ", nums.print$curveNum), adj=c(adjHor,.5), cex=cexNums)
 		
 
 	} else { #more than one series
@@ -1568,7 +1719,7 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, single
 		#in x axis move a little every series to right in order to compare
 		seqX = seq(0,length(unique(seriesName))-1,by=1)-(length(unique(seriesName))-1)/2
 
-		plot(x,y, xlab=varX, ylab="", type="n", axes=F)
+		plot(x,y, xlab=varXut, ylab="", type="n", axes=F)
 		for(i in 1:length(seriesName)) {
 			thisSerie = which(seriesName == unique(seriesName)[i])
 			colBalls[thisSerie] = uniqueColors[i]
@@ -1585,7 +1736,7 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, single
 		}
 	
 		#difficult to create a title in series graphs
-		title(paste(varX,"/",varY), cex.main=1, font.main=2)
+		title(paste(varXut,"/",varYut), cex.main=1, font.main=2)
 			
 		#plot legend on top exactly out
 		#http://stackoverflow.com/a/7322792
@@ -1603,17 +1754,18 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, single
 	if(isAlone == "ALONE") {
 		axis(1)
 		axis(2)
-		mtext(varY, side=2, line=3)
+		mtext(varYut, side=2, line=3)
 		#box()
 	} else if(isAlone == "LEFT") {
 		axis(1)
 		axis(2,col=colBalls)
-		mtext(varY, side=2, line=3, col=colBalls)
+		mtext(varYut, side=2, line=3, col=colBalls)
 		#box()
 	} else { #"RIGHT"
 		axis(4,col=colBalls)
-		mtext(varY, side=4, line=3, col=colBalls)
+		mtext(varYut, side=4, line=3, col=colBalls)
 	}
+	box()
 
 }
 
@@ -2008,6 +2160,8 @@ doProcess <- function(options) {
 	#print(options[30])
 	#print(options[31])
 
+	#options 32 is this graph.R file and it's used in call_graph.R to call this as source (in RDotNet)
+
 
 	print(File)
 	print(OutputGraph)
@@ -2318,6 +2472,8 @@ doProcess <- function(options) {
 
 			#plot speed
 			par(new=T)	
+			
+			smoothingAll= 0.1
 			speed <- getSpeed(displacement, smoothingAll)
 			plot((1:length(displacement))/1000, speed$y, col="green2",
 		     		type="l", 
@@ -2630,22 +2786,24 @@ doProcess <- function(options) {
 			print(AnalysisVariables[3])
 
 			if(AnalysisVariables[1] == "Speed,Power") {
-				par(mar=c(5,4,4,5))
+				par(mar=c(5,4,5,5))
 				analysisVertVars = unlist(strsplit(AnalysisVariables[1], "\\,"))
 				paintCrossVariables(paf, AnalysisVariables[2], analysisVertVars[1], 
-						    AnalysisVariables[3], "LEFT", Title,
+						    AnalysisVariables[3], "LEFT", "",
 						    singleFile,Eccon,mySeries, 
 						    FALSE, FALSE, OutputData1) 
 				par(new=T)
 				paintCrossVariables(paf, AnalysisVariables[2], analysisVertVars[2], 
-						    AnalysisVariables[3], "RIGHT", "",
+						    AnalysisVariables[3], "RIGHT", Title,
 						    singleFile,Eccon,mySeries, 
 						    FALSE, FALSE, OutputData1) 
-			} else
+			} else {
+				par(mar=c(5,4,5,2))
 				paintCrossVariables(paf, AnalysisVariables[2], AnalysisVariables[1], 
 						    AnalysisVariables[3], "ALONE", Title,
 						    singleFile,Eccon,mySeries, 
 						    FALSE, FALSE, OutputData1) 
+			}
 		}
 		else if(Analysis == "1RMAnyExercise") {
 			mySeries = "1"
@@ -2674,7 +2832,7 @@ doProcess <- function(options) {
 			}
 			npj <- neuromuscularProfileGetData(displacement, curves, (MassBody + MassExtra), SmoothingOneC)
 
-			if(npj == -1) {
+			if(is.double(npj) && npj == -1) {
 				plot(0,0,type="n",axes=F,xlab="",ylab="")
 				text(x=0,y=0,paste(translate("Not enough data."), "\n",
 						   translate("Need at least three jumps executed on the odd concentric phases"),
@@ -2832,7 +2990,7 @@ doProcess <- function(options) {
 						    kn$speedy, kn$accely, kn$force, kn$power))
 		}
 
-		rownames(df) = c("MEAN (ABS)", "MAX", "TIME TO MAX", "RANGE", 1:maxLength)
+		rownames(df) = c("MEAN", "MAX", "TIME TO MAX", "RANGE", 1:maxLength)
 		colnames(df) = namesNums
 
 		#TODO: time
@@ -2858,11 +3016,4 @@ doProcess <- function(options) {
 	warnings()
 }
 
-write(paste("(2/5)",translate("Loading libraries")), OutputData2)
-
-loadLibraries(OperatingSystem)
-	
-write(paste("(3/5)",translate("Starting process")), OutputData2)
-
-doProcess(options)
 
