@@ -81,9 +81,11 @@ public class Constants
 	
 	public const string FvIndexFormula = "F/V sj+(100%)/sj *100";
 	public const string IeIndexFormula = "IE (cmj-sj)/sj *100";
-	public const string IubIndexFormula = "IUB (abk-cmj)/cmj *100";
 	public const string IRnaIndexFormula = "IRna (djna-cmj)/cmj *100";
 	public const string IRaIndexFormula = "IRa (dja-cmj)/cmj *100";
+	
+	public const string ArmsUseIndexFormula = "Arms Use Index (abk-cmj)/cmj *100";
+	public const string ArmsUseIndexName = "Arms Use Index";
 
 	public const string SubtractionBetweenTests = "Subtraction between tests";
 
@@ -125,6 +127,7 @@ public class Constants
 	public const string MultiChronopicTable = "multiChronopic";
 	public const string TempMultiChronopicTable = "tempMultiChronopic"; //TODO
 	public const string EncoderTable = "encoder";
+	public const string EncoderSignalCurveTable = "encoderSignalCurve";
 	public const string EncoderExerciseTable = "encoderExercise";
 	public const string Encoder1RMTable = "encoder1RM";
 
@@ -135,6 +138,7 @@ public class Constants
 	public const string RunIntervalTypeTable = "runIntervalType";
 	public const string PulseTypeTable = "pulseType";
 	public const string ReactionTimeTypeTable = "reactionTimeType";
+	public const string GraphLinkTable = "graphLinkTable";
 
 	public const string UndefinedDefault = "Undefined";
 	public const string Any = "Any";
@@ -254,11 +258,12 @@ public class Constants
 	public static string PotencySayersCMJFormula = PotencySayersCMJFormulaShort + "\n" +
 		"(51.9*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (48.9*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -2007";
-	
+
+	//http://www.ncbi.nlm.nih.gov/pubmed/14658372	
 	public static string PotencyShettyFormulaShort = Catalog.GetString("Peak power") + " (Shetty, 2002)";
 	public static string PotencyShettyFormula = PotencyShettyFormulaShort + "\n" +
-		"(1925.72*" + Catalog.GetString("height") + "(cm))" +
-	        "+ (14.74*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -66.3";
+		"(1925.72*" + Catalog.GetString("height") + "(m))" +
+	        "+ (14.74*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -666.3";
 	
 	public static string PotencyCanavanFormulaShort = Catalog.GetString("Peak power") + " (Canavan, 2004)";
 	public static string PotencyCanavanFormula = PotencyCanavanFormulaShort + "\n" +
@@ -416,6 +421,10 @@ public class Constants
 	public static string FileNameAutoPersonSkipIcon = "auto-person-skip.png";
 	public static string FileNameAutoPersonRemoveIcon = "auto-person-remove.png";
 	
+	public static string FileNameSelectorJumps = "chronojump-jumps-small.png";
+	public static string FileNameSelectorRuns = "chronojump-runs-small.png";
+	public static string FileNameSelectorEncoder = "chronojump-encoder-small.jpg";
+	
 	//30 colors defined
 	//see als UtilGtk that's not used by the server
 	public static string [] Colors = {
@@ -635,6 +644,11 @@ public class Constants
 		JUMPS, RUNS, ENCODER
 	}
 
+	public static string All = "All";
+	public static string None = "None";
+	public static string Invert = "Invert";
+	public static string Selected = "Selected";
+
 	/*
 	 * encoder storage
 	 * chronojump / encoder / sessionID / data
@@ -643,6 +657,7 @@ public class Constants
 	
 	public static string EncoderScriptCaptureLinux = "pyserial_pyper.py";
 	public static string EncoderScriptCaptureWindows = "pyserial_pyper_windows.exe";
+	public static string EncoderScriptCallGraph = "call_graph.R";
 	public static string EncoderScriptGraph = "graph.R";
 	public static string EncoderScriptInertiaMomentum = "inertia-momentum.R";
 	public static string EncoderScriptUtilR = "util.R";
@@ -733,6 +748,7 @@ public class Constants
 		FIRST, AVERAGE, LAST
 	}
 	
+	//DISPLACED means: total
 	public enum MassType {
 		BODY, EXTRA, DISPLACED
 	}	
@@ -757,9 +773,9 @@ public class Constants
 		"Time to Peak Power",
 		"time",
 		"Range",
-		"height",
+		"distance",
 		"Weight",
-		"Load",
+		"Mass",
 		"eccentric",
 		"concentric",
 		"land",
@@ -803,9 +819,9 @@ public class Constants
 		Catalog.GetString("Time to Peak Power"),
 		Catalog.GetString("time"),
 		Catalog.GetString("Range"),
-		Catalog.GetString("height"),
+		Catalog.GetString("distance"),
 		Catalog.GetString("Weight"),
-		Catalog.GetString("Load"),
+		Catalog.GetString("Mass"),
 		Catalog.GetString("eccentric"),
 		Catalog.GetString("concentric"),
 		Catalog.GetString("land"),
