@@ -191,19 +191,92 @@ public class EncoderStruct
 	~EncoderStruct() {}
 }
 
+public class EncoderGraphROptions
+{
+	public string inputData;
+	public string outputGraph;
+	public string outputData1;
+	public string outputData2;
+	public string specialData;
+	public EncoderParams ep;
+	public string title;
+	public string operatingSystem;
+	public string scriptUtilR;
+	public string scriptNeuromuscularProfile;
+	public string englishWords;
+	public string translatedWords;
+	public string scriptGraphR;
+	
+	public EncoderGraphROptions(
+			string inputData, string outputGraph, string outputData1, 
+			string outputData2, string specialData, 
+			EncoderParams ep,
+			string title, string operatingSystem,
+			string scriptUtilR, string scriptNeuromuscularProfile,
+			string englishWords, string translatedWords,
+			string scriptGraphR) 
+	{
+		this.inputData = inputData;
+		this.outputGraph = outputGraph;
+		this.outputData1 = outputData1;
+		this.outputData2 = outputData2;
+		this.specialData = specialData;
+		this.ep = ep;
+		this.title = title;
+		this.operatingSystem = operatingSystem;
+		this.scriptUtilR = scriptUtilR;
+		this.scriptNeuromuscularProfile = scriptNeuromuscularProfile;
+		this.englishWords = englishWords;
+		this.translatedWords = translatedWords;
+		this.scriptGraphR = scriptGraphR;
+	}
+
+	public override string ToString() {
+		return inputData + "\n" + 
+			outputGraph + "\n" + outputData1 + "\n" + 
+			outputData2 + "\n" + specialData + "\n" + 
+			ep.ToString2("\n") + "\n" + title + "\n" + operatingSystem + "\n" +
+			scriptUtilR + "\n" + scriptNeuromuscularProfile + "\n" +
+			englishWords + "\n" +
+			translatedWords + "\n" + 
+			scriptGraphR + "\n";
+	}
+
+	~EncoderGraphROptions() {}
+}
+
+
 //used on TreeViews capture and analyze
 public class EncoderCurve
 {
+	public bool Record;	//only on capture
+	public string N;
+	public string Series;
+	public string Exercise;
+	public double ExtraWeight;
+	public double DisplacedWeight;
+	public string Start;
+	public string Duration;
+	public string Height;
+	public string MeanSpeed;
+	public string MaxSpeed;
+	public string MaxSpeedT;
+	public string MeanPower;
+	public string PeakPower;
+	public string PeakPowerT;
+	public string PP_PPT;
+	
 	public EncoderCurve () {
 	}
 
 	//used on TreeView capture
-	public EncoderCurve (string n, 
+	public EncoderCurve (bool record, string n, 
 			string start, string duration, string height, 
 			string meanSpeed, string maxSpeed, string maxSpeedT,
 			string meanPower, string peakPower, string peakPowerT, 
 			string PP_PPT)
 	{
+		this.Record = record;
 		this.N = n;
 		this.Start = start;
 		this.Duration = duration;
@@ -252,24 +325,31 @@ public class EncoderCurve
 			MeanPower + sep + PeakPower + sep + PeakPowerT + sep + 
 			PP_PPT;
 	}
-
-	public string N;
-	public string Series;
-	public string Exercise;
-	public double ExtraWeight;
-	public double DisplacedWeight;
-	public string Start;
-	public string Duration;
-	public string Height;
-	public string MeanSpeed;
-	public string MaxSpeed;
-	public string MaxSpeedT;
-	public string MeanPower;
-	public string PeakPower;
-	public string PeakPowerT;
-	public string PP_PPT;
 }
 
+//related to encoderSignalCurve table
+public class EncoderSignalCurve {
+	public int uniqueID;
+	public int signalID;
+	public int curveID;
+	public int msCentral;
+	
+	public EncoderSignalCurve(int uniqueID, int signalID, int curveID, int msCentral) {
+		this.uniqueID = uniqueID;
+		this.signalID = signalID;
+		this.curveID = curveID;
+		this.msCentral = msCentral;
+	}
+	
+	public string ToString() {
+		return uniqueID.ToString() + ":" + signalID.ToString() + ":" + 
+			curveID.ToString() + ":" + msCentral.ToString();
+	}
+	
+	~EncoderSignalCurve() {}
+}
+
+
 //used on TreeView
 public class EncoderNeuromuscularData
 {
@@ -442,7 +522,7 @@ public class EncoderSQL
 		this.status = status;
 		this.videoURL = videoURL;
 		this.encoderConfiguration = encoderConfiguration;
-		this.future1 = future1;
+		this.future1 = future1;	//on signals: meanPower
 		this.future2 = future2;
 		this.future3 = future3;
 		this.exerciseName = exerciseName;
@@ -479,12 +559,15 @@ public class EncoderSQL
 		return str;
 	}
 
-	public string [] ToStringArray (int count, bool checkboxes, bool video, bool encoderConfigPretty) {
+	//showMeanPower is used in curves, but not in signal
+	public string [] ToStringArray (int count, bool checkboxes, bool video, bool encoderConfigPretty, bool showMeanPower) {
 		int all = 9;
 		if(checkboxes)
 			all ++;
 		if(video)
 			all++;
+		if(showMeanPower)
+			all++;
 
 
 		string [] str = new String [all];
@@ -496,7 +579,11 @@ public class EncoderSQL
 	
 		str[i++] = count.ToString();
 		str[i++] = exerciseName;
+		str[i++] = laterality;
 		str[i++] = extraWeight;
+		
+		if(showMeanPower)
+			str[i++] = future1;
 
 		if(encoderConfigPretty)
 			str[i++] = encoderConfiguration.ToStringPretty();
@@ -816,7 +903,7 @@ public class EncoderConfiguration {
 			code = "Linear - inertial machine";
 			text = Catalog.GetString("Linear encoder on inertia machine.") + "\n" + 
 				Catalog.GetString("Configuration NOT Recommended! Please use a rotary encoder.") + "\n" +
-				Catalog.GetString("Person has to start fully extended (on the toes).");
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*";
 			
 			has_d = true;
 			has_inertia = true;
@@ -918,7 +1005,7 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderFrictionSideInertial;
 			code = "Rotary friction - inertial machine side";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine side.") + "\n" +
-				Catalog.GetString("Person has to start fully extended (on the toes).");
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*";
 
 			has_d = true;
 			has_D = true;
@@ -930,7 +1017,7 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderFrictionAxisInertial;
 			code = "Rotary friction axis - inertial machine axis";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine axis.") + "\n" +
-				Catalog.GetString("Person has to start fully extended (on the toes).");
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*";
 
 			has_d = true;
 			has_inertia = true;
@@ -957,7 +1044,7 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderAxisInertial;
 			code = "Rotary axis - inertial machine";
 			text = Catalog.GetString("Rotary axis encoder on inertial machine.") + "\n" +
-			Catalog.GetString("Person has to start fully extended (on the toes).");
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*";
 
 			has_d = true;
 			has_inertia = true;
