@@ -152,11 +152,11 @@ public class ExportSession
 	protected virtual void getData() 
 	{
 		myPersons = SqlitePersonSession.SelectCurrentSessionPersons(mySession.UniqueID);
-		myJumps= SqliteJump.SelectJumps(mySession.UniqueID, -1, "", "");
+		myJumps= SqliteJump.SelectJumps(false, mySession.UniqueID, -1, "", "");
 		myJumpsRj = SqliteJumpRj.SelectJumps(mySession.UniqueID, -1, "", "");
-		myRuns= SqliteRun.SelectRuns(mySession.UniqueID, -1, "");
+		myRuns= SqliteRun.SelectRuns(false, mySession.UniqueID, -1, "");
 		myRunsInterval = SqliteRunInterval.SelectRuns(mySession.UniqueID, -1, "");
-		myReactionTimes = SqliteReactionTime.SelectReactionTimes(mySession.UniqueID, -1);
+		myReactionTimes = SqliteReactionTime.SelectReactionTimes(false, mySession.UniqueID, -1);
 		myPulses = SqlitePulse.SelectPulses(mySession.UniqueID, -1);
 		myMCs = SqliteMultiChronopic.SelectTests(mySession.UniqueID, -1);
 	}
@@ -874,19 +874,23 @@ public class ExportSessionCSV : ExportSession
 	}
 
 	protected override void writeData (ArrayList exportData) {
-		for(int i=0; i < exportData.Count ; i++) {
-			//if the locale of this user shows the decimal point as ',', show it as '.' for not confusing with the comma separator
-			//exportData[i] = exportData[i].ToString().Replace(",", ".");
-
+		for(int i=0; i < exportData.Count ; i++) 
+		{
 			//correctly separate the rows with no problems with decimals
-			//1 delete the ';'
+			//delete the ';'
 			exportData[i] = exportData[i].ToString().Replace(";", " ");
-			/*
-			//2 put '; ' as separator
-			exportData[i] = exportData[i].ToString().Replace(":", "; ");
-			*/
-			//2 put ';' as separator
-			exportData[i] = exportData[i].ToString().Replace(":", ";");
+			
+			bool latin = true;
+
+			if(latin) {
+				//put ';' as separator
+				exportData[i] = exportData[i].ToString().Replace(":", ";");
+			} else {
+				//decimal as "."
+				exportData[i] = exportData[i].ToString().Replace(",", ".");
+				//put ',' as separator
+				exportData[i] = exportData[i].ToString().Replace(":", ",");
+			}
 
 			writer.WriteLine( exportData[i] );
 		}
