@@ -39,17 +39,17 @@ public partial class ChronoJumpWindow
 		bool showStartAndDuration = encoderCaptureOptionsWin.check_show_start_and_duration.Active;
 
 		string [] columnsString = {
-			Catalog.GetString("Curve") + "\n",
+			Catalog.GetString("n") + "\n",
 			Catalog.GetString("Start") + "\n (s)",
 			Catalog.GetString("Duration") + "\n (s)",
-			Catalog.GetString("Range") + "\n (cm)",
-			Catalog.GetString("MeanSpeed") + "\n (m/s)",
-			Catalog.GetString("MaxSpeed") + "\n (m/s)",
-			Catalog.GetString("MaxSpeedTime") + "\n (s)",
-			Catalog.GetString("MeanPower") + "\n (W)",
-			Catalog.GetString("PeakPower") + "\n (W)",
-			Catalog.GetString("PeakPowerTime") + "\n (s)",
-			Catalog.GetString("PeakPower/PPT") + "\n (W/s)"
+			Catalog.GetString("Distance") + "\n (cm)",
+			"v" + "\n (m/s)",
+			"vmax" + "\n (m/s)",
+			"t->vmax" + "\n (s)",
+			"p" + "\n (W)",
+			"pmax" + "\n (W)",
+			"t->pmax" + "\n (s)",
+			"pmax/t->pmax" + "\n (W/s)"
 		};
 
 		encoderCaptureCurves = new ArrayList ();
@@ -71,6 +71,7 @@ public partial class ChronoJumpWindow
 				cells = fixDecimals(cells);
 
 				encoderCaptureCurves.Add (new EncoderCurve (
+							false,				//user need to mark to save them
 							cells[0],	//id 
 							//cells[1],	//seriesName
 							//cells[2], 	//exerciseName
@@ -86,17 +87,35 @@ public partial class ChronoJumpWindow
 		}
 
 		encoderCaptureListStore = new Gtk.ListStore (typeof (EncoderCurve));
+		
 		foreach (EncoderCurve curve in encoderCaptureCurves) 
 			encoderCaptureListStore.AppendValues (curve);
 
 		treeview_encoder_capture_curves.Model = encoderCaptureListStore;
 
+		/*
 		if(ecconLast == "c")
 			treeview_encoder_capture_curves.Selection.Mode = SelectionMode.Single;
 		else
 			treeview_encoder_capture_curves.Selection.Mode = SelectionMode.Multiple;
+			*/
+		treeview_encoder_capture_curves.Selection.Mode = SelectionMode.None;
 
 		treeview_encoder_capture_curves.HeadersVisible=true;
+		
+		
+		//create first column (checkbox)	
+		CellRendererToggle crt = new CellRendererToggle();
+		crt.Visible = true;
+		crt.Activatable = true;
+		crt.Active = true;
+		crt.Toggled += ItemToggled;
+		Gtk.TreeViewColumn column = new Gtk.TreeViewColumn ();
+
+		column.Title = Catalog.GetString("Saved");
+		column.PackStart (crt, true);
+		column.SetCellDataFunc (crt, new Gtk.TreeCellDataFunc (RenderRecord));
+		treeview_encoder_capture_curves.AppendColumn (column);
 
 		int i=0;
 		foreach(string myCol in columnsString) {
@@ -105,9 +124,6 @@ public partial class ChronoJumpWindow
 			aColumn.Title=myCol;
 			aColumn.PackStart (aCell, true);
 
-			//crt1.Foreground = "red";
-			//crt1.Background = "blue";
-		
 			switch(i){	
 				case 0:
 					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderN));
@@ -150,23 +166,248 @@ public partial class ChronoJumpWindow
 		}
 		return curvesCount;
 	}
+	
+	//rowNum starts at zero
+	void saveOrDeleteCurveFromCaptureTreeView(int rowNum, EncoderCurve curve, bool save) 
+	{
+		Log.WriteLine("saving? " + save.ToString() + "; rownum:" + rowNum.ToString());
+		if(save)
+			encoderSaveSignalOrCurve("curve", rowNum +1);
+		else {
+			double msStart = Convert.ToDouble(curve.Start);
+			double msEnd = -1;
+			if(ecconLast == "c")
+				msEnd = Convert.ToDouble(curve.Start) + 
+					Convert.ToDouble(curve.Duration);
+			else {
+				EncoderCurve curveNext = 
+					treeviewEncoderCaptureCurvesGetCurve(rowNum +2,false);
+				msEnd = Convert.ToDouble(curveNext.Start) + 
+					Convert.ToDouble(curveNext.Duration);
+			}
+
+			ArrayList signalCurves = SqliteEncoder.SelectSignalCurve(false,
+					Convert.ToInt32(encoderSignalUniqueID), -1, 
+					msStart, msEnd);
+			foreach(EncoderSignalCurve esc in signalCurves)
+				delete_encoder_curve(esc.curveID);
+		}
+	}
+
+	void ItemToggled(object o, ToggledArgs args) {
+		TreeIter iter;
+		int column = 0;
+		if (encoderCaptureListStore.GetIterFromString (out iter, args.Path)) 
+		{
+			int rowNum = Convert.ToInt32(args.Path); //starts at zero
+			
+			//on "ecS" don't pass the 2nd row, pass always the first
+			//then need to move the iter to previous row
+			TreePath path = new TreePath(args.Path);
+			if(ecconLast != "c" && ! Util.IsEven(rowNum)) {
+				rowNum --;
+				path.Prev();
+				//there's no "IterPre", for this reason we use this path method:
+				encoderCaptureListStore.GetIter (out iter, path);
+			
+				/*
+				 * caution, note args.Path has not changed; but path, iter and rowNum have decreased
+				 * do not use args.Path from now
+				 */
+			}
+
+			EncoderCurve curve = (EncoderCurve) encoderCaptureListStore.GetValue (iter, column);
+			//get previous value
+			bool val = curve.Record;
+
+			//change value
+			//this changes value, but checkbox will be changed on RenderRecord. Was impossible to do here.
+			((EncoderCurve) encoderCaptureListStore.GetValue (iter, column)).Record = ! val;
+				
+			//this makes RenderRecord work on changed row without having to put mouse there
+			encoderCaptureListStore.EmitRowChanged(path,iter);
+
+			saveOrDeleteCurveFromCaptureTreeView(rowNum, curve, ! val);
+			
+			string message = "";
+			if(! val)
+				message = Catalog.GetString("Saved");
+			else
+				message = Catalog.GetString("Removed");
+			if(ecconLast ==	"c")
+				label_encoder_curve_action.Text = message + " " + (rowNum +1).ToString();
+			else
+				label_encoder_curve_action.Text = message + " " + (decimal.Truncate((rowNum +1) /2) +1).ToString();
+
+
+			//on ec, ecS need to [un]select second row
+			if (ecconLast=="ec" || ecconLast =="ecS") {
+				path.Next();
+				encoderCaptureListStore.IterNext (ref iter);
+
+				//change value
+				((EncoderCurve) encoderCaptureListStore.GetValue (iter, column)).Record = ! val;
+
+				//this makes RenderRecord work on changed row without having to put mouse there
+				encoderCaptureListStore.EmitRowChanged(path,iter);
+			}
+			
+			combo_encoder_capture_save_curve.Active = UtilGtk.ComboMakeActive(
+					combo_encoder_capture_save_curve, 
+					Catalog.GetString(Constants.Selected));
+			
+			updateUserCurvesLabelsAndCombo();
+
+			callPlotCurvesGraphDoPlot();
+		}
+	}
+
+	void encoderCaptureSelectByCombo(string toSelect) {
+		if(toSelect == Catalog.GetString(Constants.Selected))
+			return;
+
+		bool val = true;
+		if(toSelect == Catalog.GetString(Constants.None))
+			val = false;
+
+		int i = 0; //on "c": i is every row; on other eccons: i is every two rows
+		string sep = "";
+		string messageRows = "";
+		TreeIter iter;
+		bool iterOk = encoderCaptureListStore.GetIterFirst(out iter);
+		while(iterOk) {
+			TreePath path = encoderCaptureListStore.GetPath(iter);
+			
+			EncoderCurve curve = (EncoderCurve) encoderCaptureListStore.GetValue (iter, 0);
+			if(curve.Record != val) { 
+				//change value
+				((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).Record = val;
+
+				//this makes RenderRecord work on changed row without having to put mouse there
+				encoderCaptureListStore.EmitRowChanged(path,iter);
+
+				//on "ecS" don't pass the 2nd row, pass always the first
+				saveOrDeleteCurveFromCaptureTreeView(i, curve, val);
+				
+				if(ecconLast != "c") {
+					path.Next();
+					encoderCaptureListStore.IterNext (ref iter);
+				
+					//change value
+					((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).Record = val;
+
+					//this makes RenderRecord work on changed row without having to put mouse there
+					encoderCaptureListStore.EmitRowChanged(path,iter);
+				}
+					
+				messageRows += sep + (i+1).ToString();
+				sep = ", ";
+			}
+			i ++;
+			if(ecconLast != "c")
+				i ++;
+
+			iterOk = encoderCaptureListStore.IterNext (ref iter);
+		}
+		//combo_encoder_capture_show_save_curve_button();
+			
+		string message = "";
+		if(val)
+			message = Catalog.GetString("Saved");
+		else
+			message = Catalog.GetString("Removed");
+		label_encoder_curve_action.Text = message + " " + messageRows;
+
+			
+		updateUserCurvesLabelsAndCombo();
+			
+		callPlotCurvesGraphDoPlot();
+	}
+	
+	//saved curves (when load), or recently deleted curves should modify the encoderCapture treeview
+	//used also on bells close
+	void encoderCaptureSelectBySavedCurves(int msCentral, bool selectIt) {
+		TreeIter iter;
+		TreeIter iterPre;
+		bool iterOk = encoderCaptureListStore.GetIterFirst(out iter);
+		while(iterOk) {
+			TreePath path = encoderCaptureListStore.GetPath(iter);
+			EncoderCurve curve = (EncoderCurve) encoderCaptureListStore.GetValue (iter, 0);
+			
+			bool found = false;
+			string eccon = findEccon(true);
+			if(eccon == "c") {
+				if(Convert.ToDouble(curve.Start) <= msCentral && 
+						Convert.ToDouble(curve.Start) + Convert.ToDouble(curve.Duration) >= msCentral) 
+				{
+					((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).Record = selectIt;
+
+					//this makes RenderRecord work on changed row without having to put mouse there
+					encoderCaptureListStore.EmitRowChanged(path,iter);
+				}
+			}
+			else { // if(eccon == "ecS")
+				iterPre = iter; //to point at the "e" curve
+				iterOk = encoderCaptureListStore.IterNext (ref iter);
+				EncoderCurve curve2 = (EncoderCurve) encoderCaptureListStore.GetValue (iter, 0);
+
+				Log.WriteLine("msCentral, start, end" + msCentral.ToString() + " " + curve.Start + " " + 
+						(Convert.ToDouble(curve2.Start) + Convert.ToDouble(curve2.Duration)).ToString());
+
+				if(Convert.ToDouble(curve.Start) <= msCentral && 
+						Convert.ToDouble(curve2.Start) + Convert.ToDouble(curve2.Duration) >= msCentral) 
+				{
+					((EncoderCurve) encoderCaptureListStore.GetValue (iterPre, 0)).Record = selectIt;
+					((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).Record = selectIt;
+
+					//this makes RenderRecord work on changed row without having to put mouse there
+					encoderCaptureListStore.EmitRowChanged(path,iterPre);
+					encoderCaptureListStore.EmitRowChanged(path,iter);
+				}
+			}
+
+			iterOk = encoderCaptureListStore.IterNext (ref iter);
+		}
+		//combo_encoder_capture_show_save_curve_button();
+			
+		callPlotCurvesGraphDoPlot();
+	}
+
+	/*	
+	void combo_encoder_capture_show_save_curve_button () {
+		label_encoder_curve_action.Text = "";
+
+		TreeIter iter;
+		bool iterOk = encoderCaptureListStore.GetIterFirst(out iter);
+		while(iterOk) {
+			if(((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).Record) {
+				encoderButtonsSensitive(encoderSensEnum.SELECTEDCURVE);
+				return;
+			}
+			iterOk = encoderCaptureListStore.IterNext (ref iter);
+		}
+		encoderButtonsSensitive(encoderSensEnum.DONEYESSIGNAL);
+	}
+	*/
+
+
 
 	string [] treeviewEncoderAnalyzeHeaders = {
 		Catalog.GetString("Curve") + "\n",
 		Catalog.GetString("Series") + "\n",
 		Catalog.GetString("Exercise") + "\n",
 		Catalog.GetString("Extra weight") + "\n (Kg)",
-		Catalog.GetString("Displaced weight") + "\n (Kg)",
+		Catalog.GetString("Total weight") + "\n (Kg)",
 		Catalog.GetString("Start") + "\n (s)",
 		Catalog.GetString("Duration") + "\n (s)",
-		Catalog.GetString("Range") + "\n (cm)",
-		Catalog.GetString("MeanSpeed") + "\n (m/s)",
-		Catalog.GetString("MaxSpeed") + "\n (m/s)",
-		Catalog.GetString("MaxSpeedTime") + "\n (s)",
-		Catalog.GetString("MeanPower") + "\n (W)",
-		Catalog.GetString("PeakPower") + "\n (W)",
-		Catalog.GetString("PeakPowerTime") + "\n (s)",
-		Catalog.GetString("PeakPower/PPT") + "\n (W/s)"
+		Catalog.GetString("Distance") + "\n (cm)",
+		"v" + "\n (m/s)",
+		"vmax" + "\n (m/s)",
+		"t->vmax" + "\n (s)",
+		"p" + "\n (W)",
+		"pmax" + "\n (W)",
+		"t->pmax" + "\n (s)",
+		"pmax/t->pmax" + "\n (W/s)"
 	};
 
 	bool lastTreeviewEncoderAnalyzeIsNeuromuscular = false;
@@ -179,13 +420,14 @@ public partial class ChronoJumpWindow
 		//write exercise and extra weight data
 		ArrayList curvesData = new ArrayList();
 		string exerciseName = "";
-		double displacedMass = 0; 
+		double totalMass = 0; 
 		if(check_encoder_analyze_signal_or_curves.Active) {	//current signal
 			exerciseName = UtilGtk.ComboGetActive(combo_encoder_exercise);
-			displacedMass = findMass(Constants.MassType.DISPLACED);
+			totalMass = findMass(Constants.MassType.DISPLACED);
 		} else {						//user curves
 			curvesData = SqliteEncoder.Select(
-					false, -1, currentPerson.UniqueID, currentSession.UniqueID, "curve", true);
+					false, -1, currentPerson.UniqueID, currentSession.UniqueID, 
+					"curve", true, true);
 		}
 
 		string line;
@@ -207,20 +449,25 @@ public partial class ChronoJumpWindow
 				
 				if(! check_encoder_analyze_signal_or_curves.Active) {	//user curves
 					/*
+					 * better don't do this to avoid calling SQL in both treads
 					EncoderSQL eSQL = (EncoderSQL) curvesData[curvesCount];
 					exerciseName = eSQL.exerciseName;
-					displacedMass = eSQL.extraWeight;
+					totalMass = eSQL.extraWeight;
 					*/
 					exerciseName = cells[2];
-					displacedMass = Convert.ToDouble(cells[4]);
+					//cells[3]: massBody
+					//cells[4]: massExtra
+
+					totalMass = Convert.ToDouble(cells[3]) * getExercisePercentBodyWeightFromName (exerciseName) / 100.0
+						+ Convert.ToDouble(cells[4]);
 				}
 
 				encoderAnalyzeCurves.Add (new EncoderCurve (
 							cells[0], 
 							cells[1],	//seriesName 
 							exerciseName,
-						       	massWithoutPerson(displacedMass, exerciseName),
-							displacedMass,
+							Convert.ToDouble(cells[4]),
+							totalMass,
 							cells[5], cells[6], cells[7], 
 							cells[8], cells[9], cells[10], 
 							cells[11], cells[12], cells[13],
@@ -478,6 +725,10 @@ public partial class ChronoJumpWindow
 		return assignColor(found, higherActive, lowerActive, 
 				Convert.ToDouble(higherValue), Convert.ToDouble(lowerValue));
 	}
+	
+	private void RenderRecord (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter) {
+		(cell as Gtk.CellRendererToggle).Active = ((EncoderCurve) model.GetValue (iter, 0)).Record;
+	}
 
 	private void RenderN (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
@@ -612,7 +863,7 @@ public partial class ChronoJumpWindow
 
 		//no need of UtilGtk.TVNumPrint, always has 1 digit on left of decimal
 		(cell as Gtk.CellRendererText).Text = 
-			String.Format("{0,10:0.000}",Convert.ToDouble(curve.MeanSpeed));
+			String.Format("{0,8:0.000}",Convert.ToDouble(curve.MeanSpeed));
 	}
 
 	private void RenderMaxSpeed (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
@@ -631,7 +882,7 @@ public partial class ChronoJumpWindow
 
 		//no need of UtilGtk.TVNumPrint, always has 1 digit on left of decimal
 		(cell as Gtk.CellRendererText).Text = 
-			String.Format("{0,10:0.000}",Convert.ToDouble(curve.MaxSpeed));
+			String.Format("{0,8:0.000}",Convert.ToDouble(curve.MaxSpeed));
 	}
 	
 	private void RenderMaxSpeedT (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
@@ -639,7 +890,7 @@ public partial class ChronoJumpWindow
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
 		double time = Convert.ToDouble(curve.MaxSpeedT)/1000; //ms->s
 		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(time.ToString(),7,3),time);
+			String.Format(UtilGtk.TVNumPrint(time.ToString(),5,3),time);
 	}
 
 	private void RenderMeanPower (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
@@ -657,7 +908,7 @@ public partial class ChronoJumpWindow
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 
 		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(curve.MeanPower,9,3),Convert.ToDouble(curve.MeanPower));
+			String.Format(UtilGtk.TVNumPrint(curve.MeanPower,7,1),Convert.ToDouble(curve.MeanPower));
 	}
 
 	private void RenderPeakPower (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
@@ -675,7 +926,7 @@ public partial class ChronoJumpWindow
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 
 		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(curve.PeakPower,9,3),Convert.ToDouble(curve.PeakPower));
+			String.Format(UtilGtk.TVNumPrint(curve.PeakPower,7,1),Convert.ToDouble(curve.PeakPower));
 	}
 
 	private void RenderPeakPowerT (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
@@ -683,7 +934,7 @@ public partial class ChronoJumpWindow
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
 		double myPPT = Convert.ToDouble(curve.PeakPowerT)/1000; //ms->s
 		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(myPPT.ToString(),7,3),myPPT);
+			String.Format(UtilGtk.TVNumPrint(myPPT.ToString(),5,3),myPPT);
 	}
 
 	private void RenderPP_PPT (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
@@ -867,65 +1118,6 @@ public partial class ChronoJumpWindow
 		return curve;
 	}
 
-	private int treeviewEncoderCaptureCurvesEventSelectedID() {
-		TreeIter iter = new TreeIter();
-		TreeModel myModel = treeview_encoder_capture_curves.Model;
-		
-		if(ecconLast == "c") {
-			if (treeview_encoder_capture_curves.Selection.GetSelected (out myModel, out iter)) 
-				return Convert.ToInt32(((EncoderCurve) (treeview_encoder_capture_curves.Model.GetValue (iter, 0))).N); //this return an int, also in ec
-		} else {
-			int selectedLength = treeview_encoder_capture_curves.Selection.GetSelectedRows().Length;
-			if(selectedLength == 1 || selectedLength == 2) { 
-				TreePath path = treeview_encoder_capture_curves.Selection.GetSelectedRows()[0];
-				myModel.GetIter(out iter, path);
-				return Convert.ToInt32(((EncoderCurve) (treeview_encoder_capture_curves.Model.GetValue (iter, 0))).N);
-			}
-		}
-		return 0;
-	}
-	
-	private void on_treeview_encoder_capture_curves_cursor_changed (object o, EventArgs args) 
-	{
-		int lineNum = treeviewEncoderCaptureCurvesEventSelectedID();
-		encoderButtonsSensitive(encoderSensEnum.DONENOSIGNAL);
-		
-		//on ecc-con select both lines
-		if(ecconLast == "c") {
-			if (lineNum > 0)
-				encoderButtonsSensitive(encoderSensEnum.SELECTEDCURVE);
-		} else {
-			TreeIter iter = new TreeIter();
-
-			treeview_encoder_capture_curves.CursorChanged -= on_treeview_encoder_capture_curves_cursor_changed; 
-
-			if (treeview_encoder_capture_curves.Selection.GetSelectedRows().Length == 1) 
-			{
-				treeview_encoder_capture_curves.Selection.UnselectAll();
-
-				//on even, select also previous row
-				//on odd, select also next row
-				treeview_encoder_capture_curves.Model.GetIterFirst ( out iter ) ;
-				bool isEven = (lineNum % 2 == 0); //check if it's even (in spanish "par")
-				int start = lineNum;
-				if(isEven) 
-					start = lineNum-1;
-
-				//select 1st row
-				for(int i=1; i < start; i++)
-					treeview_encoder_capture_curves.Model.IterNext (ref iter);
-				treeview_encoder_capture_curves.Selection.SelectIter(iter);
-
-				//select 2nd row
-				treeview_encoder_capture_curves.Model.IterNext (ref iter);
-				treeview_encoder_capture_curves.Selection.SelectIter(iter);
-				
-				if (treeview_encoder_capture_curves.Selection.GetSelectedRows().Length == 2) 
-					encoderButtonsSensitive(encoderSensEnum.SELECTEDCURVE);
-			}
-			treeview_encoder_capture_curves.CursorChanged += on_treeview_encoder_capture_curves_cursor_changed; 
-		}
-	}
 	
 	// ---------helpful methods -----------
 	
