@@ -15,10 +15,11 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
+using System.IO;
 using Gtk;
 using Glade;
 //using Gnome;
@@ -32,6 +33,7 @@ public class ErrorWindow
 	[Widget] Gtk.Window error_window;
 	[Widget] Gtk.Label label1;
 	[Widget] Gtk.Button button_accept;
+	[Widget] Gtk.Button button_open_database_folder;
 
 	string table;
 	static ErrorWindow ErrorWindowBox;
@@ -40,7 +42,7 @@ public class ErrorWindow
 	{
 		Console.WriteLine("At error window2");
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "error_window", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "error_window", "chronojump");
 		gladeXML.Autoconnect(this);
 		
 		//put an icon to window
@@ -56,7 +58,11 @@ public class ErrorWindow
 		if (ErrorWindowBox == null) {
 			ErrorWindowBox = new ErrorWindow(text1);
 		}
-		ErrorWindowBox.error_window.Show ();
+		
+		//hidden always excepted when called to be shown (see below)
+		ErrorWindowBox.button_open_database_folder.Hide();
+
+		ErrorWindowBox.error_window.Show();
 		
 		return ErrorWindowBox;
 	}
@@ -72,6 +78,25 @@ public class ErrorWindow
 		button_accept.Click();
 	}
 	
+	public void Show_button_open_database_folder () {
+		button_open_database_folder.Show();
+	}
+	
+	private void on_button_open_database_folder_clicked (object o, EventArgs args)
+	{
+		string database_url = Util.GetDatabaseDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
+		string database_temp_url = Util.GetDatabaseTempDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
+		
+		System.IO.FileInfo file1 = new System.IO.FileInfo(database_url); //potser cal una arrobar abans (a windows)
+		System.IO.FileInfo file2 = new System.IO.FileInfo(database_temp_url); //potser cal una arrobar abans (a windows)
+
+		if(file1.Exists)
+			System.Diagnostics.Process.Start(Util.GetDatabaseDir()); 
+		else if(file2.Exists)
+			System.Diagnostics.Process.Start(Util.GetDatabaseTempDir()); 
+		else
+			new DialogMessage(Constants.MessageTypes.WARNING, Constants.DatabaseNotFound);
+	}
 
 	protected void on_button_accept_clicked (object o, EventArgs args)
 	{
