@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2011   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -1824,7 +1824,7 @@ Log.WriteLine("Preparing reactive A");
 				if(thisRunIsSimple)
 					PrepareRunSimpleGraph(currentEventExecute.PrepareEventGraphRunSimpleObject);
 				else {
-					bool volumeOnHere = true;
+					bool volumeOnHere = volumeOn;
 					//do not play good or bad sounds at RSA because we need to hear the GO sound
 					if(currentRunIntervalType.IsRSA)
 						volumeOnHere = false;
