@@ -929,11 +929,29 @@ partial class ChronoJumpWindow
 	private RunType previousRunType; //used on More to turnback if cancel or delete event is pressed
 	private RunType previousRunIntervalType; //used on More to turnback if cancel or delete event is pressed
 
+
+	//creates and if is not predefined, checks database to gather all the data
+	//simple == true  for normal runs, and false for intervallic
+	private RunType createRunType(string name, bool simple) {
+		RunType t = new RunType(name);
+		
+		if(! t.IsPredefined) {
+			if(simple) {
+				t = SqliteRunType.SelectAndReturnRunType(name, false);
+				t.ImageFileName = SqliteEvent.GraphLinkSelectFileName(Constants.RunTable, name);
+			} else {
+				t = SqliteRunIntervalType.SelectAndReturnRunIntervalType(name, false);
+				t.ImageFileName = SqliteEvent.GraphLinkSelectFileName(Constants.RunIntervalTable, name);
+			}
+		}
+		return t;
+	}
+	
 	
 	private void on_extra_window_runs_test_changed(object o, EventArgs args)
 	{
 		string runEnglishName = Util.FindOnArray(':',2,1, UtilGtk.ComboGetActive(combo_select_runs), selectRunsString);
-		currentRunType = new RunType(runEnglishName);
+		currentRunType = createRunType(runEnglishName, true);
 		
 		extra_window_runs_initialize(currentRunType);
 	}
@@ -951,7 +969,7 @@ partial class ChronoJumpWindow
 	private void on_extra_window_runs_interval_test_changed(object o, EventArgs args)
 	{
 		string runEnglishName = Util.FindOnArray(':',2,1, UtilGtk.ComboGetActive(combo_select_runs_interval), selectRunsIntervalString);
-		currentRunIntervalType = new RunType(runEnglishName);
+		currentRunIntervalType = createRunType(runEnglishName, false);
 		
 		extra_window_runs_interval_initialize(currentRunIntervalType);
 	}
@@ -1055,7 +1073,7 @@ partial class ChronoJumpWindow
 	{
 		runsMoreWin.Button_accept.Clicked -= new EventHandler(on_more_runs_accepted);
 	
-		currentRunType = new RunType(runsMoreWin.SelectedEventName);
+		currentRunType = createRunType(runsMoreWin.SelectedEventName, true);
 		
 		extra_window_runs_initialize(currentRunType);
 				
@@ -1067,7 +1085,7 @@ partial class ChronoJumpWindow
 	{
 		runsIntervalMoreWin.Button_accept.Clicked -= new EventHandler(on_more_runs_interval_accepted);
 		
-		currentRunIntervalType = new RunType(runsIntervalMoreWin.SelectedEventName);
+		currentRunIntervalType = createRunType(runsIntervalMoreWin.SelectedEventName, false);
 
 		extra_window_runs_interval_initialize(currentRunIntervalType);
 
