@@ -252,7 +252,7 @@ public class Server
 				int countE = 0;					
 				int countS = 0;					
 
-				string [] jumps = SqliteJump.SelectJumps(currentSession.UniqueID, person.UniqueID, "", "");
+				string [] jumps = SqliteJump.SelectJumps(false, currentSession.UniqueID, person.UniqueID, "", "");
 				Sqlite.Open();
 				foreach(string myJump in jumps) {
 					string [] js = myJump.Split(new char[] {':'});
@@ -365,7 +365,7 @@ public class Server
 				countE = 0;					
 				countS = 0;					
 
-				string [] runs = SqliteRun.SelectRuns(currentSession.UniqueID, person.UniqueID, "");
+				string [] runs = SqliteRun.SelectRuns(false, currentSession.UniqueID, person.UniqueID, "");
 				Sqlite.Open();
 				foreach(string myRun in runs) {
 					string [] js = myRun.Split(new char[] {':'});
@@ -452,7 +452,7 @@ public class Server
 				countE = 0;					
 				countS = 0;					
 
-				string [] rts = SqliteReactionTime.SelectReactionTimes(currentSession.UniqueID, person.UniqueID);
+				string [] rts = SqliteReactionTime.SelectReactionTimes(false, currentSession.UniqueID, person.UniqueID);
 				Sqlite.Open();
 				foreach(string myRt in rts) {
 					string [] js = myRt.Split(new char[] {':'});
