@@ -74,7 +74,7 @@ class Sqlite
 	 * Important, change this if there's any update to database
 	 * Important2: if database version get numbers higher than 1, check if the comparisons with currentVersion works ok
 	 */
-	static string lastChronojumpDatabaseVersion = "1.05";
+	static string lastChronojumpDatabaseVersion = "1.08";
 
 	public Sqlite() {
 	}
@@ -1492,6 +1492,99 @@ class Sqlite
 
 				currentVersion = "1.05";
 			}
+			if(currentVersion == "1.05") {
+				dbcon.Open();
+		
+				SqliteEncoder.createTableEncoderSignalCurve();
+
+				ArrayList signals = SqliteEncoder.Select(true, -1, -1, -1, "signal", false, false);
+				ArrayList curves = SqliteEncoder.Select(true, -1, -1, -1, "curve", false, false);
+				int signalID;
+				conversionRateTotal = signals.Count;
+				conversionRate = 1;
+				//in 1.05 curves can be related to signals only by date
+				foreach(EncoderSQL s in signals) {
+					conversionRate ++;
+					conversionSubRateTotal = curves.Count;
+					conversionSubRate = 1;
+							
+					//needed to know if there are duplicates
+					ArrayList curvesStored = new ArrayList();
+
+					foreach(EncoderSQL c in curves) {
+						conversionSubRate ++;
+						if(s.GetDate(false) == c.GetDate(false) && s.eccon == c.eccon) {
+							int msCentral = SqliteEncoder.FindCurveInSignal(
+									s.GetFullURL(false), c.GetFullURL(false));
+
+							signalID = Convert.ToInt32(s.uniqueID);
+							if(msCentral == -1)
+								signalID = -1; //mark as an orphaned curve (without signal)
+
+							/*
+							 * about duplicated curves from 1.05 and before:
+							 * There are two kind of duplicates, in both, eccon is the same, and they overlap.
+							 *
+							 * Overlapings situations:
+							 * - they are saved two times (same msCentral), or
+							 * - they are saved two times with different smoothing (different msCentral)
+							 *
+							 * from now on (1.06) there will be no more duplicates
+							 * about the old duplicated curves, is the user problem,
+							 * except the curves of the first kind, that we know exactly that they are duplicated
+							 */
+							
+							//curves come sorted by UniqueID DESC (selected with orderIDascendent = false)
+							//if does not exist: insert in encoderSignalCurve
+							bool exists = false;
+							foreach(int ms in curvesStored)
+								if(ms == msCentral)
+									exists = true;
+							if(exists) {
+								//delete this (newer will not be deleted)
+								Sqlite.Delete(true, 
+										Constants.EncoderTable, Convert.ToInt32(c.uniqueID));
+							} else {
+								curvesStored.Add(msCentral);
+								SqliteEncoder.SignalCurveInsert(true, 
+										signalID, Convert.ToInt32(c.uniqueID), msCentral);
+							}
+						}
+					}
+				}
+
+				conversionSubRate ++;
+				conversionRate ++;
+				Log.WriteLine("Curves are now linked to signals");
+				SqlitePreferences.Update ("databaseVersion", "1.06", true); 
+				
+				dbcon.Close();
+				currentVersion = "1.06";
+			}
+			if(currentVersion == "1.06") {
+				dbcon.Open();
+			
+				Update(true, Constants.GraphLinkTable, "graphFileName", "jump_dj.png", "jump_dj_a.png",
+						"eventName", "DJa");
+				
+				Log.WriteLine("Added jump_dj_a.png");
+				SqlitePreferences.Update ("databaseVersion", "1.07", true); 
+				dbcon.Close();
+
+				currentVersion = "1.07";
+			}
+			if(currentVersion == "1.07") {
+				dbcon.Open();
+			
+				Log.WriteLine("Added translate statistics graph option to preferences");
+				
+				SqlitePreferences.Insert ("RGraphsTranslate", "True"); 
+				SqlitePreferences.Update ("databaseVersion", "1.08", true); 
+				dbcon.Close();
+
+				currentVersion = "1.08";
+			}
+		
 		
 
 				
@@ -1609,6 +1702,7 @@ class Sqlite
 		//encoder	
 		creationRate ++;
 		SqliteEncoder.createTableEncoder();
+		SqliteEncoder.createTableEncoderSignalCurve();
 		SqliteEncoder.createTableEncoderExercise();
 		SqliteEncoder.initializeTableEncoderExercise();
 		SqliteEncoder.createTable1RM();
@@ -1634,10 +1728,13 @@ class Sqlite
 		SqliteCountry.initialize();
 		
 		//changes [from - to - desc]
-		//1.04 - 1-05 Converted DB to 1.05 Removed inertial curves, because sign was not checked on 1.04 when saving curves
-		//1.03 - 1-04 Converted DB to 1.04 Encoder table improved
-		//1.02 - 1-03 Converted DB to 1.03 Updated encoder exercise, angle is now on encoder configuration
-		//1.01 - 1-02 Converted DB to 1.02 Added Agility Tests: Agility-T-Test, Agility-3L3R
+		//1.07 - 1.08 Converted DB to 1.08 Added translate statistics graph option to preferences
+		//1.06 - 1.07 Converted DB to 1.07 Added jump_dj_a.png
+		//1.05 - 1.06 Converted DB to 1.06 Curves are now linked to signals
+		//1.04 - 1.05 Converted DB to 1.05 Removed inertial curves, because sign was not checked on 1.04 when saving curves
+		//1.03 - 1.04 Converted DB to 1.04 Encoder table improved
+		//1.02 - 1.03 Converted DB to 1.03 Updated encoder exercise, angle is now on encoder configuration
+		//1.01 - 1.02 Converted DB to 1.02 Added Agility Tests: Agility-T-Test, Agility-3L3R
 		//1.00 - 1.01 Converted DB to 1.01 Added export to CSV configuration on preferences
 		//0.99 - 1.00 Converted DB to 1.00 Encoder added Free and Inclinated Exercises
 		//0.98 - 0.99 Converted DB to 0.99 Encoder table improved 
@@ -2447,6 +2544,21 @@ Console.WriteLine("5" + tableName);
 		if( ! dbconOpened)
 			dbcon.Close();
 	}
+	
+	public static void DeleteSelectingField(bool dbconOpened, string tableName, string fieldName, string id)
+	{
+		if( ! dbconOpened)
+			dbcon.Open();
+
+		dbcmd.CommandText = "Delete FROM " + tableName +
+			" WHERE " + fieldName + " == " + id;
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		
+		if( ! dbconOpened)
+			dbcon.Close();
+	}
+
 
 	public static void DeleteFromName(bool dbconOpened, string tableName, string name)
 	{
