@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -40,7 +40,7 @@ using Mono.Unix;
  *		StatRjIndex
  *	StatPotencyBosco
  *	StatIE
- *		StatIUB
+ *		StatIUB //Arms Use Index
  * 	StatGlobal	//suitable for global and for a unique jumper
  *
  * ---------------------------------------
