@@ -25,6 +25,9 @@ using System.Collections; //ArrayList
 using System.Diagnostics; 	//for detect OS
 using System.IO; 		//for detect OS
 
+using System.Linq;	//RDotNet
+using RDotNet;		//RDotNet
+
 //this class tries to be a space for methods that are used in different classes
 public class UtilEncoder
 {
@@ -156,7 +159,18 @@ public class UtilEncoder
 					Util.GetDataDir(), "encoder", Constants.EncoderScriptCaptureLinux);
 	}
 	
-	private static string getEncoderScriptGraph() {
+
+	/*
+	 * in RDotNet, graph.R is in memory, and call_graph.R is not called
+	 * if RDotNet is not working, then call_graph.R is called and this calls graph.R
+	 */
+
+	private static string getEncoderScriptCallGraph() {
+		return System.IO.Path.Combine(
+				Util.GetDataDir(), "encoder", Constants.EncoderScriptCallGraph);
+	}
+
+	public static string GetEncoderScriptGraph() {
 		return System.IO.Path.Combine(
 				Util.GetDataDir(), "encoder", Constants.EncoderScriptGraph);
 	}
@@ -241,33 +255,93 @@ public class UtilEncoder
 	}
 	*/
 	
-	public static bool RunEncoderGraph(string title, EncoderStruct es, bool neuromuscularProfileDo) 
+	public static REngine RunEncoderCaptureCsharpInitializeR(REngine rengine, out Constants.Status RInitialized) 
 	{
-		CancelRScript = false;
-
-		ProcessStartInfo pinfo;
-	        Process p;
-		//If output file is not given, R will try to write in the running folder
-		//in which we may haven't got permissions
+		Log.WriteLine("initializing rdotnet");
 		
-		string pBin="";
-		pinfo = new ProcessStartInfo();
+		//RDotNet.StartupParameter rsup = new RDotNet.StartupParameter();
+		//rsup.Interactive = false;
+		//rsup.Quiet = false;
 
-		string operatingSystem = "Linux";
+		rengine = REngine.CreateInstance("RDotNet");
 		
+		// From v1.5, REngine requires explicit initialization.
+		// You can set some parameters.
+
+		try {
+			//rengine.Initialize(rsup);
+			rengine.Initialize();
+		} catch {
+			RInitialized = Constants.Status.ERROR;
+			return rengine;
+		}
+		//Previous command, unfortunatelly localizes all GUI to english
+		//then call Catalog.Init again in order to see new windows localised		
+		//Catalog.Init("chronojump",System.IO.Path.Combine(Util.GetPrefixDir(),"share/locale"));
+
+		//load extrema method copied from EMD package
+		string utilRPath = GetEncoderScriptUtilR();
+		string graphRPath = GetEncoderScriptGraph();
+		
+		//On win32 R understands backlash as an escape character and 
+		//a file path uses Unix-like path separator '/'
+		if(UtilAll.IsWindows()) {
+			utilRPath = utilRPath.Replace("\\","/");
+			graphRPath = graphRPath.Replace("\\","/");
+		}
+		Log.WriteLine(utilRPath);
+		Log.WriteLine(graphRPath);
+		
+		try {
+			//load extrema
+			rengine.Evaluate("source('" + utilRPath + "')");
+			//load more stuff and call later using RDotNet
+			rengine.Evaluate("source('" + graphRPath + "')");
+		} catch {
+			RInitialized = Constants.Status.ERROR;
+			return rengine;
+		}
+
+		try {
+			// .NET Framework array to R vector.
+			NumericVector group1 = rengine.CreateNumericVector(new double[] { 30.02, 29.99, 30.11, 29.97, 30.01, 29.99 });
+			rengine.SetSymbol("group1", group1);
+			// Direct parsing from R script.
+			NumericVector group2 = rengine.Evaluate("group2 <- c(29.89, 29.93, 29.72, 29.98, 30.02, 29.98)").AsNumeric();
+
+			// Test difference of mean and get the P-value.
+			GenericVector testResult = rengine.Evaluate("t.test(group1, group2)").AsList();
+			double p = testResult["p.value"].AsNumeric().First();
+
+			Console.WriteLine("Group1: [{0}]", string.Join(", ", group1));
+			Console.WriteLine("Group2: [{0}]", string.Join(", ", group2));
+			Console.WriteLine("P-value = {0:0.000}", p);
+		} catch {
+			RInitialized = Constants.Status.ERROR;
+			return rengine;
+		}
+
+		Log.WriteLine("initialized rdotnet");
+		
+		RInitialized = Constants.Status.OK;
+
+		return rengine;
+	}
+	
+	
+	private static EncoderGraphROptions prepareEncoderGraphOptions(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate) 
+	{
 		string scriptUtilR = GetEncoderScriptUtilR();
 
 		string scriptNeuromuscularProfile = "none"; //cannot be blank
 		if(neuromuscularProfileDo)
 			scriptNeuromuscularProfile = GetEncoderScriptNeuromuscularProfile();
-			
-		pBin="Rscript";
-		//pBin="R";
-		if (UtilAll.IsWindows()) {
-			//on Windows we need the \"str\" to call without problems in path with spaces
-			pBin = "\"" + System.IO.Path.Combine(Util.GetPrefixDir(), "bin" + Path.DirectorySeparatorChar + "Rscript.exe") + "\"";
-			Log.WriteLine("pBin:" + pBin);
 
+		string scriptGraphR = GetEncoderScriptGraph();
+		
+		string operatingSystem = "Linux";
+		
+		if (UtilAll.IsWindows()) {
 			//convert accents to Unicode in order to be plotted correctly on R windows
 			title = Util.ConvertToUnicode(title);
 
@@ -280,6 +354,7 @@ public class UtilEncoder
 			es.SpecialData = es.SpecialData.Replace("\\","/");
 			scriptUtilR = scriptUtilR.Replace("\\","/");
 			scriptNeuromuscularProfile = scriptNeuromuscularProfile.Replace("\\","/");
+			scriptGraphR = scriptGraphR.Replace("\\","/");
 			operatingSystem = "Windows";
 		}
 		
@@ -288,21 +363,117 @@ public class UtilEncoder
 		int count = 0;
 		string temp = "";
 		string [] encoderTranslatedWordsOK = new String [Constants.EncoderTranslatedWords.Length];
-		foreach(string etw in Constants.EncoderTranslatedWords) {
-			temp = Util.ChangeChars(etw, ";", ",");
-			temp = Util.RemoveNewLine(temp, true);
-			encoderTranslatedWordsOK[count++] = temp;
+
+		//if ! translate, then just print the english words
+		if(translate) {
+			foreach(string etw in Constants.EncoderTranslatedWords) {
+				temp = Util.ChangeChars(etw, ";", ",");
+				temp = Util.RemoveNewLine(temp, true);
+				encoderTranslatedWordsOK[count++] = temp;
+			}
+		} else
+			encoderTranslatedWordsOK = Constants.EncoderEnglishWords;
+
+		return new EncoderGraphROptions( 
+				es.InputData, es.OutputGraph, es.OutputData1, 
+				es.OutputData2, es.SpecialData, 
+				es.Ep,
+				title, operatingSystem,
+				scriptUtilR, scriptNeuromuscularProfile,
+				Util.StringArrayToString(Constants.EncoderEnglishWords,";"),
+				Util.StringArrayToString(encoderTranslatedWordsOK,";"), 
+				scriptGraphR);
+	}
+
+	/*	
+	 *	Currently unused because this was called in main thread and when a pulse thread exists
+	 *	It should be without threading or in the GTK thread
+	 *	Now graph call is so fast with the call_graph.R
+	 *	then there's no need to add the complexity of calling RunEncoderGraphRDotNet outside the thread
+	 *	because the GTK thread has some interesting things that it does when it ends.
+	 *	We have enough speed now and we don't want to add more bugs
+	 *
+	public static bool RunEncoderGraph(REngine rengine, Constants.Status RInitialized,
+			string title, EncoderStruct es, bool neuromuscularProfileDo) 
+	{
+		if(RInitialized == Constants.Status.UNSTARTED)
+			RunEncoderCaptureCsharpInitializeR(rengine, out RInitialized);
+		
+		bool result = false;
+		if(RInitialized == Constants.Status.ERROR)
+			result = RunEncoderGraphNoRDotNet(title, es, neuromuscularProfileDo);
+		else if(RInitialized == Constants.Status.OK)
+			result = RunEncoderGraphRDotNet(rengine, title, es, neuromuscularProfileDo);
+
+		return result;
+	}
+
+	//this method uses RDotNet
+	public static bool RunEncoderGraphRDotNet(REngine rengine, string title, EncoderStruct es, bool neuromuscularProfileDo) 
+	{
+		//if RDotNet is ok, graph.R is already loaded
+		rengine.Evaluate("meanPower <- mean(c(2,3,4,5,6,7,8))");
+		double meanPower = rengine.GetSymbol("meanPower").AsNumeric().First();
+		Log.WriteLine(meanPower.ToString());
+		rengine.Evaluate("print(findPosInPaf(\"Power\", \"max\"))");
+
+		EncoderGraphROptions roptions = prepareEncoderGraphOptions(title, es, neuromuscularProfileDo);
+		Log.WriteLine(roptions.ToString());	
+
+		//--------------------------------------------
+		//		Attention
+		//this code should be the same as call_graph.R
+		//--------------------------------------------
+
+		//TODO: pass roptions to RDotNet objects and then call graph.R
+		CharacterVector charVec;
+	
+		Log.WriteLine("-1-");	
+		string str_string = roptions.outputData2;
+		Log.WriteLine(str_string);
+		
+		charVec = rengine.CreateCharacterVector(new[] { str_string });
+		rengine.SetSymbol("OutputData2", charVec);
+	
+		Log.WriteLine("-2-");	
+		Log.WriteLine(roptions.specialData);	
+		Log.WriteLine("-3-");	
+		CharacterVector charVec2 = rengine.CreateCharacterVector(new[] { roptions.specialData });
+		rengine.SetSymbol("SpecialData", charVec2);
+		
+		Log.WriteLine(roptions.operatingSystem);	
+		charVec = rengine.CreateCharacterVector(new[] { roptions.operatingSystem });
+		rengine.SetSymbol("OperatingSystem", charVec);
+
+		return true;
+	}
+	*/
+
+	/*
+	 * this method don't use RDotNet, then has to call call_graph.R, who will call graph.R
+	 * and has to write a Roptions.txt file
+	 */
+	public static bool RunEncoderGraphNoRDotNet(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate) 
+	{
+		CancelRScript = false;
+
+		ProcessStartInfo pinfo;
+	        Process p;
+		//If output file is not given, R will try to write in the running folder
+		//in which we may haven't got permissions
+		
+		string pBin="";
+		pinfo = new ProcessStartInfo();
+
+		pBin="Rscript";
+		if (UtilAll.IsWindows()) {
+			//on Windows we need the \"str\" to call without problems in path with spaces
+			pBin = "\"" + System.IO.Path.Combine(Util.GetPrefixDir(), "bin" + Path.DirectorySeparatorChar + "Rscript.exe") + "\"";
+			Log.WriteLine("pBin:" + pBin);
 		}
+		
 
-		//--- way A. passing options to a file
-		string scriptOptions = es.InputData + "\n" + 
-		es.OutputGraph + "\n" + es.OutputData1 + "\n" + 
-		es.OutputData2 + "\n" + es.SpecialData + "\n" + 
-		es.Ep.ToString2("\n") + "\n" + title + "\n" + operatingSystem + "\n" +
-		scriptUtilR + "\n" + scriptNeuromuscularProfile + "\n" +
-		Util.StringArrayToString(Constants.EncoderEnglishWords,";") + "\n" +
-		Util.StringArrayToString(encoderTranslatedWordsOK,";") + "\n";
-
+		string scriptOptions = prepareEncoderGraphOptions(title, es, neuromuscularProfileDo, translate).ToString();
 
 		string optionsFile = Path.GetTempPath() + "Roptions.txt";
 		TextWriter writer = File.CreateText(optionsFile);
@@ -317,32 +488,12 @@ public class UtilEncoder
 		}
 		
 		//on Windows we need the \"str\" to call without problems in path with spaces
-		pinfo.Arguments = "\"" + getEncoderScriptGraph() + "\" " + optionsFile;
+		pinfo.Arguments = "\"" + getEncoderScriptCallGraph() + "\" " + optionsFile;
 	
 		Log.WriteLine("Arguments:" + pinfo.Arguments);
-		
-		/*
-		pinfo.Arguments = "CMD BATCH --no-save '--args optionsFile=\"" + optionsFile + "\"' \"" + 
-			getEncoderScriptGraph() + "\" \"" + 
-			Path.GetTempPath() + "error.txt\"";
-			*/
-		
-		//--- way B. put options as arguments
-		/*
-		string argumentOptions = es.InputData + " " + 
-			es.OutputGraph + " " + es.OutputData1 + " " + es.OutputData2 + " " + 
-			es.Ep.ToString2(" ") + " " + title;
-		
-		pinfo.Arguments = getEncoderScriptGraph() + " " + argumentOptions;
-		*/
-
-		Log.WriteLine("------------- 1 ---");
-		Log.WriteLine(optionsFile.ToString());
-		Log.WriteLine("------------- 2 ---");
-		Log.WriteLine(scriptOptions.ToString());
-		Log.WriteLine("------------- 3 ---");
-		Log.WriteLine(pinfo.Arguments.ToString());
-		Log.WriteLine("------------- 4 ---");
+		Log.WriteLine("--- 1 --- " + optionsFile.ToString() + " ---");
+		Log.WriteLine("--- 2 --- " + scriptOptions + " ---");
+		Log.WriteLine("--- 3 --- " + pinfo.Arguments.ToString() + " ---");
 		
 		string outputFileCheck = "";
 		string outputFileCheck2 = "";
@@ -524,21 +675,6 @@ public class UtilEncoder
 		return returnStr;
 	}
 
-	public static void EncoderDeleteCurveFromSignal(string fileName, int start, int duration) {
-		string contents = Util.ReadFile(fileName, false);
-		string [] startAndDuration = encoderFindPos(contents, start, duration);
-
-		StringBuilder myStringBuilder = new StringBuilder(contents);
-		myStringBuilder.Remove(
-				Convert.ToInt32(startAndDuration[0]),
-				Convert.ToInt32(startAndDuration[1]));
-		contents = myStringBuilder.ToString();
-		
-		TextWriter writer = File.CreateText(fileName);
-		writer.Write(contents);
-		writer.Flush();
-		((IDisposable)writer).Dispose();
-	}
 
 	public static string EncoderSaveCurve(string fileNameSignal, 
 			int start, int duration, 
