@@ -253,6 +253,7 @@ public class UtilGtk
 	public static Gdk.Color BLACK = new Gdk.Color(0x00,0x00,0x00);
 	public static Gdk.Color BLUE = new Gdk.Color(0x6c,0x77,0xab);
 	public static Gdk.Color BLUE_CLEAR = new Gdk.Color(0xa0,0xa7,0xca);
+	public static Gdk.Color YELLOW = new Gdk.Color(0xff,0xcc,0x01);
 	
 	public static Gdk.Color GREEN_PLOTS = new Gdk.Color(0,238,0);
 	public static Gdk.Color RED_PLOTS = new Gdk.Color(238,0,0);
@@ -260,6 +261,14 @@ public class UtilGtk
 	public static Gdk.Color BLUE_PLOTS = new Gdk.Color(0,0,238);
 	public static Gdk.Color BLUE_CHRONOJUMP = new Gdk.Color(14,30,70); //so dark, can be used only for background
 	
+	public static Gdk.Color SELECTED = GetBackgroundColorSelected();
+
+
+	public static Gdk.Color GetBackgroundColorSelected() {
+		Gtk.Style regularLabel = Gtk.Rc.GetStyle (new Gtk.Label());
+
+		return regularLabel.Background (StateType.Selected);
+	}
 
 	public static void ColorsMenuLabel(Gtk.Viewport v, Gtk.Label l) {
 		l.ModifyFg(StateType.Active, v.Style.Foreground(StateType.Selected));
@@ -318,7 +327,7 @@ public class UtilGtk
 			l2.ModifyFg(StateType.Normal, WHITE);
 		}
 	}
-
+	
 	/*
 	 *
 	 * PRETTY THINGS
